==> production-demo-20260209_092413.tar.gz: var/www/html/production-demo/var/tmp/twig/64/640e48d185dd257ca94cc2274aea72cd.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/LeftPanel/index.html.twig */
class __TwigTemplate_a899a4d633a833d62fd15e3a20a5e07c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        $context["extraMenu"] = $this->extensions['Mautic\CoreBundle\Twig\Extension\MenuExtension']->menuRender("extra");
        // line 2
        if ( !Twig\Extension\CoreExtension::testEmpty((isset($context["extraMenu"]) || array_key_exists("extraMenu", $context) ? $context["extraMenu"] : (function () { throw new RuntimeError('Variable "extraMenu" does not exist.', 2, $this->source); })()))) {
            // line 3
            yield "    <!-- start: sidebar-header -->
    <div class=\"sidebar-header\">
        <a class=\"mautic-brand";
            // line 5
            yield ((Twig\Extension\CoreExtension::testEmpty((isset($context["extraMenu"]) || array_key_exists("extraMenu", $context) ? $context["extraMenu"] : (function () { throw new RuntimeError('Variable "extraMenu" does not exist.', 5, $this->source); })()))) ? ("") : (" pull-left pl-0 pr-0"));
            yield "\" href=\"#\">
            <div class=\"dropdown extra-menu\">
                <a href=\"#\" data-toggle=\"dropdown\" class=\"dropdown-toggle\">
                    <i class=\"ri-arrow-down-s-line ri-lg\"></i>
                </a>
                ";
            // line 10
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape((isset($context["extraMenu"]) || array_key_exists("extraMenu", $context) ? $context["extraMenu"] : (function () { throw new RuntimeError('Variable "extraMenu" does not exist.', 10, $this->source); })()), "html", null, true);
            yield "
            </div>
        </a>
    </div>
    <!--/ end: sidebar-header -->
";
        }
        // line 16
        yield "

<!-- start: sidebar-content -->
<div class=\"sidebar-content\">
    <!-- scroll-content -->
    <div class=\"scroll-content slimscroll\">
        <!-- start: navigation -->
        <nav class=\"nav-sidebar\">
            ";
        // line 24
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ContentExtension']->getCustomContent("menu.above", $context);
        yield "
            ";
        // line 25
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\MenuExtension']->menuRender("main");
        yield "

            <!-- start: left nav -->
            <ul class=\"nav sidebar-left-dark\"></ul>
            <!--/ end: left nav -->

        </nav>
        <!--/ end: navigation -->
    </div>
    <!--/ scroll-content -->
</div>
<!--/ end: sidebar-content -->";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/LeftPanel/index.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  81 => 25,  77 => 24,  67 => 16,  58 => 10,  50 => 5,  46 => 3,  44 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/LeftPanel/index.html.twig", "/var/www/html/mauticGIT-Test/app/bundles/CoreBundle/Resources/views/LeftPanel/index.html.twig");
    }
}

==> production-demo-20260209_093043.tar.gz: var/www/html/production-demo/var/tmp/twig/64/640e48d185dd257ca94cc2274aea72cd.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @MauticCore/LeftPanel/index.html.twig */
class __TwigTemplate_a899a4d633a833d62fd15e3a20a5e07c extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        $context["extraMenu"] = $this->extensions['Mautic\CoreBundle\Twig\Extension\MenuExtension']->menuRender("extra");
        // line 2
        if ( !Twig\Extension\CoreExtension::testEmpty((isset($context["extraMenu"]) || array_key_exists("extraMenu", $context) ? $context["extraMenu"] : (function () { throw new RuntimeError('Variable "extraMenu" does not exist.', 2, $this->source); })()))) {
            // line 3
            yield "    <!-- start: sidebar-header -->
    <div class=\"sidebar-header\">
        <a class=\"mautic-brand";
            // line 5
            yield ((Twig\Extension\CoreExtension::testEmpty((isset($context["extraMenu"]) || array_key_exists("extraMenu", $context) ? $context["extraMenu"] : (function () { throw new RuntimeError('Variable "extraMenu" does not exist.', 5, $this->source); })()))) ? ("") : (" pull-left pl-0 pr-0"));
            yield "\" href=\"#\">
            <div class=\"dropdown extra-menu\">
                <a href=\"#\" data-toggle=\"dropdown\" class=\"dropdown-toggle\">
                    <i class=\"ri-arrow-down-s-line ri-lg\"></i>
                </a>
                ";
            // line 10
            yield $this->env->getRuntime('Twig\Runtime\EscaperRuntime')->escape((isset($context["extraMenu"]) || array_key_exists("extraMenu", $context) ? $context["extraMenu"] : (function () { throw new RuntimeError('Variable "extraMenu" does not exist.', 10, $this->source); })()), "html", null, true);
            yield "
            </div>
        </a>
    </div>
    <!--/ end: sidebar-header -->
";
        }
        // line 16
        yield "

<!-- start: sidebar-content -->
<div class=\"sidebar-content\">
    <!-- scroll-content -->
    <div class=\"scroll-content slimscroll\">
        <!-- start: navigation -->
        <nav class=\"nav-sidebar\">
            ";
        // line 24
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\ContentExtension']->getCustomContent("menu.above", $context);
        yield "
            ";
        // line 25
        yield $this->extensions['Mautic\CoreBundle\Twig\Extension\MenuExtension']->menuRender("main");
        yield "

            <!-- start: left nav -->
            <ul class=\"nav sidebar-left-dark\"></ul>
            <!--/ end: left nav -->

        </nav>
        <!--/ end: navigation -->
    </div>
    <!--/ scroll-content -->
</div>
<!--/ end: sidebar-content -->";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@MauticCore/LeftPanel/index.html.twig";
    }

    /**
     * @codeCoverageIgnore
     */
    public function isTraitable(): bool
    {
        return false;
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  81 => 25,  77 => 24,  67 => 16,  58 => 10,  50 => 5,  46 => 3,  44 => 2,  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@MauticCore/LeftPanel/index.html.twig", "/var/www/html/production-demo/app/bundles/CoreBundle/Resources/views/LeftPanel/index.html.twig");
    }
}
